pub enum QueuePriority {
Low = 0,
Normal = 1,
High = 2,
}Expand description
Frame priority for queue ordering.
Frames are dequeued in strict priority order: High → Normal → Low. Within the same priority, frames are dequeued in FIFO order.
Variants
Low = 0
Lowest priority: diagnostics, bus monitor, property responses.
Normal = 1
Default priority: regular data frames.
High = 2
Highest priority: confirmations, resets, system frames.
Implementations
Sourceimpl QueuePriority
impl QueuePriority
Sourcepub fn classify(message_code: MessageCode) -> Self
pub fn classify(message_code: MessageCode) -> Self
Classify a frame by its message code into a priority level.
Sourcepub fn all_descending() -> &'static [QueuePriority]
pub fn all_descending() -> &'static [QueuePriority]
All priority levels in descending order (highest first).